NPi.GPIO README

This is a [RPi.GPIO.NP](https://github.com/chainsx/RPi.GPIO.NP) fork, with some fixes and installable from [PyPI](https://pypi.org/project/NPi.GPIO/). As the project from which it is derived, it is based on the original [RPi.GPIO](https://pypi.python.org/pypi/RPi.GPIO) (same for the API).   
  
__It work with Python2.x and Python 3.x__

### APT 
#### Common requirements
    sudo apt update
    sudo apt install python-dev 

### PyPI
#### Installation
    sudo pip install NPi.GPIO

### GIT
#### Download
    git clone https://github.com/Tungsteno74/NPi.GPIO

#### Installation
    cd /NPi.GPIO               
    sudo python setup.py install
